==> SugarCE-5.5.1.zip: SugarCE-Full-5.5.1/modules/ProjectTask/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/



$mod_strings = array (
	'LBL_MODULE_NAME' => 'Project Tasks',
	'LBL_MODULE_TITLE' => 'Project Task: Home',
	'LBL_SEARCH_FORM_TITLE' => 'Project Task Search',
	'LBL_LIST_FORM_TITLE'=> 'Project Task List',
    'LBL_EDIT_TASK_IN_GRID_TITLE'=> 'Edit Task In Grid',    
	
	'LBL_ID' => 'Id:',
    'LBL_PROJECT_TASK_ID' => 'Project Task Id:',
    'LBL_PROJECT_ID' => 'Project Id:',
	'LBL_DATE_ENTERED' => 'Date Entered:',
	'LBL_DATE_MODIFIED' => 'Date Modified:',
	'LBL_ASSIGNED_USER_ID' => 'Assigned To:',
	'LBL_MODIFIED_USER_ID' => 'Modified User Id:',
	'LBL_CREATED_BY' => 'Created By:',
	'LBL_TEAM_ID' => 'Team:',
	'LBL_NAME' => 'Name:',
	'LBL_STATUS' => 'Status:',
	'LBL_DATE_DUE' => 'Due Date:',
	'LBL_TIME_DUE' => 'Due Time:',
    'LBL_RESOURCE' => 'Resource:',
    'LBL_PREDECESSORS' => 'Predecessors:',
	'LBL_DATE_START' => 'Start Date:',
    'LBL_DATE_FINISH' => 'Finish Date:',    
	'LBL_TIME_START' => 'Start Time:',
    'LBL_TIME_FINISH' => 'Finish Time:',
    'LBL_DURATION' => 'Duration:',
    'LBL_DURATION_UNIT' => 'Duration Unit:',
    'LBL_ACTUAL_DURATION' => 'Actual Duration:',
	'LBL_PARENT_ID' => 'Project:',
    'LBL_PARENT_TASK_ID' => 'Parent Task Id:',    
    'LBL_PERCENT_COMPLETE' => 'Percent Complete (%):',
	'LBL_PRIORITY' => 'Priority:',
	'LBL_DESCRIPTION' => 'Description:',
	'LBL_ORDER_NUMBER' => 'Order:',
	'LBL_TASK_NUMBER' => 'Task Number:',
    'LBL_TASK_ID' => 'Task ID:',
	'LBL_DEPENDS_ON_ID' => 'Depends On:',
	'LBL_MILESTONE_FLAG' => 'Milestone:',
	'LBL_ESTIMATED_EFFORT' => 'Estimated Effort (hrs):',
	'LBL_ACTUAL_EFFORT' => 'Actual Effort (hrs):',
	'LBL_UTILIZATION' => 'Utilization (%):',
	'LBL_DELETED' => 'Deleted:',

	'LBL_LIST_ORDER_NUMBER' => 'Order',
	'LBL_LIST_NAME' => 'Name',
    'LBL_LIST_DAYS' => 'days',
	'LBL_LIST_PARENT_NAME' => 'Project',
	'LBL_LIST_PERCENT_COMPLETE' => 'Percent Complete (%)',
	'LBL_LIST_STATUS' => 'Status',
    'LBL_LIST_DURATION' => 'Duration',
    'LBL_LIST_ACTUAL_DURATION' => 'Actual Duration',
	'LBL_LIST_ASSIGNED_USER_ID' => 'Assigned To',
	'LBL_LIST_DATE_DUE' => 'Date Due',
	'LBL_LIST_DATE_START' => 'Start Date',
    'LBL_LIST_DATE_FINISH' => 'Finish Date',    
	'LBL_LIST_PRIORITY' => 'Priority',
	'LBL_LIST_CLOSE' => 'Close',
	'LBL_PROJECT_NAME' => 'Project Name',

	'LNK_NEW_PROJECT'	=> 'Create Project',
	'LNK_PROJECT_LIST'	=> 'Project List',
	'LNK_NEW_PROJECT_TASK'	=> 'Create Project Task',
	'LNK_PROJECT_TASK_LIST'	=> 'Project Tasks',
	
	'LBL_LIST_MY_PROJECT_TASKS' => 'My Project Tasks',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Project Tasks',
	'LBL_NEW_FORM_TITLE' => 'New Project Task',

	'LBL_ACTIVITIES_TITLE'=>'Activities',
	'LBL_HISTORY_TITLE'=>'History',
	'LBL_ACTIVITIES_SUBPANEL_TITLE'=>'Activities',
	'LBL_HISTORY_SUBPANEL_TITLE'=>'History', 
	'DATE_JS_ERROR' => 'Please enter a date corresponding to the time entered',

    'LBL_ASSIGNED_USER_NAME' => 'Assigned To',
    'LBL_PARENT_NAME' => 'Project Name',
    'LBL_LIST_PROJECT_NAME' => 'Projects',
);
?>

==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/modules/ProjectTask/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/




$mod_strings = array (
	'LBL_MODULE_NAME' => 'Project Tasks',
	'LBL_MODULE_TITLE' => 'Project Task: Home',
	'LBL_SEARCH_FORM_TITLE' => 'Project Task Search',
	'LBL_LIST_FORM_TITLE'=> 'Project Task List',
    'LBL_EDIT_TASK_IN_GRID_TITLE'=> 'Edit Task In Grid',    
	
	'LBL_ID' => 'Id:',
    'LBL_PROJECT_TASK_ID' => 'Project Task Id:',
    'LBL_PROJECT_ID' => 'Project Id:',
	'LBL_DATE_ENTERED' => 'Date Created:',
	'LBL_DATE_MODIFIED' => 'Date Modified:',
	'LBL_ASSIGNED_USER_ID' => 'Assigned To:',
	'LBL_MODIFIED_USER_ID' => 'Modified User Id:',
	'LBL_CREATED_BY' => 'Created By:',
	'LBL_TEAM_ID' => 'Team:',
	'LBL_NAME' => 'Name:',
	'LBL_STATUS' => 'Status:',
	'LBL_DATE_DUE' => 'Due Date:',
	'LBL_TIME_DUE' => 'Due Time:',
    'LBL_RESOURCE' => 'Resource:',
    'LBL_PREDECESSORS' => 'Predecessors:',
	'LBL_DATE_START' => 'Start Date:',
    'LBL_DATE_FINISH' => 'Finish Date:',    
	'LBL_TIME_START' => 'Start Time:',
    'LBL_TIME_FINISH' => 'Finish Time:',
    'LBL_DURATION' => 'Duration:',
    'LBL_DURATION_UNIT' => 'Duration Unit:',
    'LBL_ACTUAL_DURATION' => 'Actual Duration:',
	'LBL_PARENT_ID' => 'Project:',
    'LBL_PARENT_TASK_ID' => 'Parent Task Id:',    
    'LBL_PERCENT_COMPLETE' => '% Complete:',
	'LBL_PRIORITY' => 'Priority:',
	'LBL_DESCRIPTION' => 'Description:',
	'LBL_ORDER_NUMBER' => 'Order:',
	'LBL_TASK_NUMBER' => 'Task Number:',
    'LBL_TASK_ID' => 'Task ID:',
	'LBL_DEPENDS_ON_ID' => 'Depends On:',
	'LBL_MILESTONE_FLAG' => 'Milestone:',
	'LBL_ESTIMATED_EFFORT' => 'Estimated Effort (hrs):',
	'LBL_ACTUAL_EFFORT' => 'Actual Effort (hrs):',
	'LBL_UTILIZATION' => 'Utilization (%):',
	'LBL_DELETED' => 'Deleted:',

	'LBL_LIST_ORDER_NUMBER' => 'Order',
	'LBL_LIST_NAME' => 'Name',
    'LBL_LIST_DAYS' => 'days',
	'LBL_LIST_PARENT_NAME' => 'Project',
	'LBL_LIST_PERCENT_COMPLETE' => '% Complete',
	'LBL_LIST_STATUS' => 'Status',
    'LBL_LIST_DURATION' => 'Duration',
    'LBL_LIST_ACTUAL_DURATION' => 'Actual Duration',
	'LBL_LIST_ASSIGNED_USER_ID' => 'Assigned To',
	'LBL_LIST_DATE_DUE' => 'Date Due',
	'LBL_LIST_DATE_START' => 'Start Date',
    'LBL_LIST_DATE_FINISH' => 'Finish Date',    
	'LBL_LIST_PRIORITY' => 'Priority',
	'LBL_LIST_CLOSE' => 'Close',
	'LBL_PROJECT_NAME' => 'Project Name',

	'LNK_NEW_PROJECT'	=> 'Create Project',
	'LNK_PROJECT_LIST'	=> 'Project List',
	'LNK_NEW_PROJECT_TASK'	=> 'Create Project Task',
	'LNK_PROJECT_TASK_LIST'	=> 'Project Tasks',
	
	'LBL_LIST_MY_PROJECT_TASKS' => 'My Project Tasks',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Project Tasks',
	'LBL_NEW_FORM_TITLE' => 'New Project Task',

	'LBL_ACTIVITIES_TITLE'=>'Activities',
	'LBL_HISTORY_TITLE'=>'History',
	'LBL_ACTIVITIES_SUBPANEL_TITLE'=>'Activities',
	'LBL_HISTORY_SUBPANEL_TITLE'=>'History', 
	'DATE_JS_ERROR' => 'Please enter a date corresponding to the time entered',

    'LBL_ASSIGNED_USER_NAME' => 'Assigned To',
    'LBL_PARENT_NAME' => 'Project Name',
    'LBL_LIST_PROJECT_NAME' => 'Projects',
);
?>
